@@ -104,6 +104,7 @@ Dialog::Dialog(QWidget *parent) :
     country = new GConfItem(GCONF_PATH_CLOCK + "/country");
     offset = new GConfItem(GCONF_PATH_CLOCK + "/offset");
     timeZone = new GConfItem(GCONF_PATH_CLOCK + "/time_zone");
+    customFormat = new GConfItem(GCONF_PATH_CLOCK + "/custom_format");
 
     /*
      * Initialize UI with the values stored in gconf.
@@ -123,6 +124,7 @@ Dialog::Dialog(QWidget *parent) :
     ui->fontComboBox->setCurrentIndex(fontNames.indexOf(fontName->value().toString()));
     ui->textScalingSpinBox->setValue(textScaling->value().toFloat() * 100);
     ui->padZerosCheckBox->setChecked(padZeros->value().toBool());
+    ui->customFormatLineEdit->setText(customFormat->value().toString());
 
     /*
      * Get time zones and initialize combo box.
@@ -170,6 +172,7 @@ Dialog::~Dialog()
     delete country;
     delete offset;
     delete timeZone;
+    delete customFormat;
 #endif
 }
 
@@ -199,6 +202,8 @@ void Dialog::accept(){
     offset->set(time_get_utc_offset(timeZones.at(tzIndex).toUtf8().data()));
     timeZone->set(timeZones.at(tzIndex));
 
+    customFormat->set(ui->customFormatLineEdit->text());
+
     /*
      * Hack to get things updated even when the clock is not changed.
      * This is currently needed as the settings are currently updated
